@@ -32,29 +32,25 @@ import frozendict  # noqa: F401
 
 from snaptrade_client import schemas  # noqa: F401
 
-from snaptrade_client.model.action import Action as ActionSchema
 from snaptrade_client.model.model400_failed_request_response import Model400FailedRequestResponse as Model400FailedRequestResponseSchema
-from snaptrade_client.model.stop_price import StopPrice as StopPriceSchema
+from snaptrade_client.model.action_strict import ActionStrict as ActionStrictSchema
 from snaptrade_client.model.units_nullable import UnitsNullable as UnitsNullableSchema
 from snaptrade_client.model.notional_value_nullable import NotionalValueNullable as NotionalValueNullableSchema
 from snaptrade_client.model.account_order_record import AccountOrderRecord as AccountOrderRecordSchema
-from snaptrade_client.model.order_type import OrderType as OrderTypeSchema
 from snaptrade_client.model.manual_trade_form import ManualTradeForm as ManualTradeFormSchema
 from snaptrade_client.model.model403_failed_request_response import Model403FailedRequestResponse as Model403FailedRequestResponseSchema
-from snaptrade_client.model.price import Price as PriceSchema
 from snaptrade_client.model.time_in_force_strict import TimeInForceStrict as TimeInForceStrictSchema
+from snaptrade_client.model.order_type_strict import OrderTypeStrict as OrderTypeStrictSchema
 
-from snaptrade_client.type.action import Action
 from snaptrade_client.type.notional_value_nullable import NotionalValueNullable
 from snaptrade_client.type.units_nullable import UnitsNullable
 from snaptrade_client.type.manual_trade_form import ManualTradeForm
 from snaptrade_client.type.model400_failed_request_response import Model400FailedRequestResponse
+from snaptrade_client.type.action_strict import ActionStrict
 from snaptrade_client.type.time_in_force_strict import TimeInForceStrict
-from snaptrade_client.type.stop_price import StopPrice
 from snaptrade_client.type.model403_failed_request_response import Model403FailedRequestResponse
 from snaptrade_client.type.account_order_record import AccountOrderRecord
-from snaptrade_client.type.price import Price
-from snaptrade_client.type.order_type import OrderType
+from snaptrade_client.type.order_type_strict import OrderTypeStrict
 
 from . import path
 
@@ -205,16 +201,16 @@ class BaseApi(api_client.Api):
     def _place_force_order_mapped_args(
         self,
         body: typing.Optional[ManualTradeForm] = None,
+        account_id: typing.Optional[str] = None,
+        action: typing.Optional[ActionStrict] = None,
+        universal_symbol_id: typing.Optional[str] = None,
+        order_type: typing.Optional[OrderTypeStrict] = None,
+        time_in_force: typing.Optional[TimeInForceStrict] = None,
         user_id: typing.Optional[str] = None,
         user_secret: typing.Optional[str] = None,
-        account_id: typing.Optional[str] = None,
-        action: typing.Optional[Action] = None,
-        order_type: typing.Optional[OrderType] = None,
-        price: typing.Optional[Price] = None,
-        stop: typing.Optional[StopPrice] = None,
-        time_in_force: typing.Optional[TimeInForceStrict] = None,
+        price: typing.Optional[typing.Optional[typing.Union[int, float]]] = None,
+        stop: typing.Optional[typing.Optional[typing.Union[int, float]]] = None,
         units: typing.Optional[UnitsNullable] = None,
-        universal_symbol_id: typing.Optional[str] = None,
         notional_value: typing.Optional[NotionalValueNullable] = None,
         query_params: typing.Optional[dict] = {},
     ) -> api_client.MappedArgs:
@@ -225,18 +221,18 @@ class BaseApi(api_client.Api):
             _body["account_id"] = account_id
         if action is not None:
             _body["action"] = action
+        if universal_symbol_id is not None:
+            _body["universal_symbol_id"] = universal_symbol_id
         if order_type is not None:
             _body["order_type"] = order_type
+        if time_in_force is not None:
+            _body["time_in_force"] = time_in_force
         if price is not None:
             _body["price"] = price
         if stop is not None:
             _body["stop"] = stop
-        if time_in_force is not None:
-            _body["time_in_force"] = time_in_force
         if units is not None:
             _body["units"] = units
-        if universal_symbol_id is not None:
-            _body["universal_symbol_id"] = universal_symbol_id
         if notional_value is not None:
             _body["notional_value"] = notional_value
         args.body = body if body is not None else _body
@@ -263,7 +259,7 @@ class BaseApi(api_client.Api):
         AsyncGeneratorResponse,
     ]:
         """
-        Place a trade with NO validation.
+        Place order
         :param skip_deserialization: If true then api_response.response will be set but
             api_response.body and api_response.headers will not be deserialized into schema
             class instances
@@ -394,7 +390,7 @@ class BaseApi(api_client.Api):
         api_client.ApiResponseWithoutDeserialization,
     ]:
         """
-        Place a trade with NO validation.
+        Place order
         :param skip_deserialization: If true then api_response.response will be set but
             api_response.body and api_response.headers will not be deserialized into schema
             class instances
@@ -486,16 +482,16 @@ class PlaceForceOrder(BaseApi):
     async def aplace_force_order(
         self,
         body: typing.Optional[ManualTradeForm] = None,
+        account_id: typing.Optional[str] = None,
+        action: typing.Optional[ActionStrict] = None,
+        universal_symbol_id: typing.Optional[str] = None,
+        order_type: typing.Optional[OrderTypeStrict] = None,
+        time_in_force: typing.Optional[TimeInForceStrict] = None,
         user_id: typing.Optional[str] = None,
         user_secret: typing.Optional[str] = None,
-        account_id: typing.Optional[str] = None,
-        action: typing.Optional[Action] = None,
-        order_type: typing.Optional[OrderType] = None,
-        price: typing.Optional[Price] = None,
-        stop: typing.Optional[StopPrice] = None,
-        time_in_force: typing.Optional[TimeInForceStrict] = None,
+        price: typing.Optional[typing.Optional[typing.Union[int, float]]] = None,
+        stop: typing.Optional[typing.Optional[typing.Union[int, float]]] = None,
         units: typing.Optional[UnitsNullable] = None,
-        universal_symbol_id: typing.Optional[str] = None,
         notional_value: typing.Optional[NotionalValueNullable] = None,
         query_params: typing.Optional[dict] = {},
         **kwargs,
@@ -507,16 +503,16 @@ class PlaceForceOrder(BaseApi):
         args = self._place_force_order_mapped_args(
             body=body,
             query_params=query_params,
-            user_id=user_id,
-            user_secret=user_secret,
             account_id=account_id,
             action=action,
+            universal_symbol_id=universal_symbol_id,
             order_type=order_type,
+            time_in_force=time_in_force,
+            user_id=user_id,
+            user_secret=user_secret,
             price=price,
             stop=stop,
-            time_in_force=time_in_force,
             units=units,
-            universal_symbol_id=universal_symbol_id,
             notional_value=notional_value,
         )
         return await self._aplace_force_order_oapg(
@@ -528,35 +524,36 @@ class PlaceForceOrder(BaseApi):
     def place_force_order(
         self,
         body: typing.Optional[ManualTradeForm] = None,
+        account_id: typing.Optional[str] = None,
+        action: typing.Optional[ActionStrict] = None,
+        universal_symbol_id: typing.Optional[str] = None,
+        order_type: typing.Optional[OrderTypeStrict] = None,
+        time_in_force: typing.Optional[TimeInForceStrict] = None,
         user_id: typing.Optional[str] = None,
         user_secret: typing.Optional[str] = None,
-        account_id: typing.Optional[str] = None,
-        action: typing.Optional[Action] = None,
-        order_type: typing.Optional[OrderType] = None,
-        price: typing.Optional[Price] = None,
-        stop: typing.Optional[StopPrice] = None,
-        time_in_force: typing.Optional[TimeInForceStrict] = None,
+        price: typing.Optional[typing.Optional[typing.Union[int, float]]] = None,
+        stop: typing.Optional[typing.Optional[typing.Union[int, float]]] = None,
         units: typing.Optional[UnitsNullable] = None,
-        universal_symbol_id: typing.Optional[str] = None,
         notional_value: typing.Optional[NotionalValueNullable] = None,
         query_params: typing.Optional[dict] = {},
     ) -> typing.Union[
         ApiResponseFor200,
         api_client.ApiResponseWithoutDeserialization,
     ]:
+        """ Places a brokerage order in the specified account. The order could be rejected by the brokerage if it is invalid or if the account does not have sufficient funds.  This endpoint does not compute the impact to the account balance from the order and any potential commissions before submitting the order to the brokerage. If that is desired, you can use the [check order impact endpoint](/reference/Trading/Trading_getOrderImpact).  It's recommended to trigger a manual refresh of the account after placing an order to ensure the account is up to date. You can use the [manual refresh](/reference/Connections/Connections_refreshBrokerageAuthorization) endpoint for this.  """
         args = self._place_force_order_mapped_args(
             body=body,
             query_params=query_params,
-            user_id=user_id,
-            user_secret=user_secret,
             account_id=account_id,
             action=action,
+            universal_symbol_id=universal_symbol_id,
             order_type=order_type,
+            time_in_force=time_in_force,
+            user_id=user_id,
+            user_secret=user_secret,
             price=price,
             stop=stop,
-            time_in_force=time_in_force,
             units=units,
-            universal_symbol_id=universal_symbol_id,
             notional_value=notional_value,
         )
         return self._place_force_order_oapg(
@@ -570,16 +567,16 @@ class ApiForpost(BaseApi):
     async def apost(
         self,
         body: typing.Optional[ManualTradeForm] = None,
+        account_id: typing.Optional[str] = None,
+        action: typing.Optional[ActionStrict] = None,
+        universal_symbol_id: typing.Optional[str] = None,
+        order_type: typing.Optional[OrderTypeStrict] = None,
+        time_in_force: typing.Optional[TimeInForceStrict] = None,
         user_id: typing.Optional[str] = None,
         user_secret: typing.Optional[str] = None,
-        account_id: typing.Optional[str] = None,
-        action: typing.Optional[Action] = None,
-        order_type: typing.Optional[OrderType] = None,
-        price: typing.Optional[Price] = None,
-        stop: typing.Optional[StopPrice] = None,
-        time_in_force: typing.Optional[TimeInForceStrict] = None,
+        price: typing.Optional[typing.Optional[typing.Union[int, float]]] = None,
+        stop: typing.Optional[typing.Optional[typing.Union[int, float]]] = None,
         units: typing.Optional[UnitsNullable] = None,
-        universal_symbol_id: typing.Optional[str] = None,
         notional_value: typing.Optional[NotionalValueNullable] = None,
         query_params: typing.Optional[dict] = {},
         **kwargs,
@@ -591,16 +588,16 @@ class ApiForpost(BaseApi):
         args = self._place_force_order_mapped_args(
             body=body,
             query_params=query_params,
-            user_id=user_id,
-            user_secret=user_secret,
             account_id=account_id,
             action=action,
+            universal_symbol_id=universal_symbol_id,
             order_type=order_type,
+            time_in_force=time_in_force,
+            user_id=user_id,
+            user_secret=user_secret,
             price=price,
             stop=stop,
-            time_in_force=time_in_force,
             units=units,
-            universal_symbol_id=universal_symbol_id,
             notional_value=notional_value,
         )
         return await self._aplace_force_order_oapg(
@@ -612,35 +609,36 @@ class ApiForpost(BaseApi):
     def post(
         self,
         body: typing.Optional[ManualTradeForm] = None,
+        account_id: typing.Optional[str] = None,
+        action: typing.Optional[ActionStrict] = None,
+        universal_symbol_id: typing.Optional[str] = None,
+        order_type: typing.Optional[OrderTypeStrict] = None,
+        time_in_force: typing.Optional[TimeInForceStrict] = None,
         user_id: typing.Optional[str] = None,
         user_secret: typing.Optional[str] = None,
-        account_id: typing.Optional[str] = None,
-        action: typing.Optional[Action] = None,
-        order_type: typing.Optional[OrderType] = None,
-        price: typing.Optional[Price] = None,
-        stop: typing.Optional[StopPrice] = None,
-        time_in_force: typing.Optional[TimeInForceStrict] = None,
+        price: typing.Optional[typing.Optional[typing.Union[int, float]]] = None,
+        stop: typing.Optional[typing.Optional[typing.Union[int, float]]] = None,
         units: typing.Optional[UnitsNullable] = None,
-        universal_symbol_id: typing.Optional[str] = None,
         notional_value: typing.Optional[NotionalValueNullable] = None,
         query_params: typing.Optional[dict] = {},
     ) -> typing.Union[
         ApiResponseFor200,
         api_client.ApiResponseWithoutDeserialization,
     ]:
+        """ Places a brokerage order in the specified account. The order could be rejected by the brokerage if it is invalid or if the account does not have sufficient funds.  This endpoint does not compute the impact to the account balance from the order and any potential commissions before submitting the order to the brokerage. If that is desired, you can use the [check order impact endpoint](/reference/Trading/Trading_getOrderImpact).  It's recommended to trigger a manual refresh of the account after placing an order to ensure the account is up to date. You can use the [manual refresh](/reference/Connections/Connections_refreshBrokerageAuthorization) endpoint for this.  """
         args = self._place_force_order_mapped_args(
             body=body,
             query_params=query_params,
-            user_id=user_id,
-            user_secret=user_secret,
             account_id=account_id,
             action=action,
+            universal_symbol_id=universal_symbol_id,
             order_type=order_type,
+            time_in_force=time_in_force,
+            user_id=user_id,
+            user_secret=user_secret,
             price=price,
             stop=stop,
-            time_in_force=time_in_force,
             units=units,
-            universal_symbol_id=universal_symbol_id,
             notional_value=notional_value,
         )
         return self._place_force_order_oapg(
